import { PrimitivePropsWithRef } from '@radix-ui/react-primitive';
import * as React from 'react';

/**
 * Supported `Component` nodes.
 */
declare const NODES: readonly ["a", "button", "div", "footer", "form", "header", "h2", "h3", "img", "input", "label", "li", "main", "nav", "ol", "p", "span", "svg", "ul"];
/**
 * Type to define generic `Component` props.
 */
type IComponentProps = {
    cx?: ((...args: unknown[]) => string) | undefined;
};
/**
 * Type to define the supported `Component` nodes.
 */
type Components = {
    [E in (typeof NODES)[number]]: ComponentForwardRefComponent<E>;
};
/**
 * Type to define `Component` props with the 'ref' prop.
 */
type ComponentPropsWithRef<E extends React.ElementType> = PrimitivePropsWithRef<E> & IComponentProps;
/**
 * Type to define `Component` as a forwarded ref component.
 */
interface ComponentForwardRefComponent<E extends React.ElementType> extends React.ForwardRefExoticComponent<ComponentPropsWithRef<E>> {
}
/**
 * `Component` - a higher-order component that extends standard html tags.
 */
declare const Component: Components;

export { Component, type ComponentPropsWithRef };
